@@ -26,12 +26,13 @@ class CentOSScraper(ArizonaMirror):
                 continue
 
             version_number = link_version.replace("-stream", "") \
-                                         .replace(".", "")
+                                         .replace(".", "") \
+                                         .replace("/", "")
 
             # Check if link is an OS version link (only numbers)
             if version_number.isnumeric():
                 # Extract number
-                release_link_number = float(version_number[:-1])
+                release_link_number = float(version_number)
 
                 # Update latest release if necessary
                 if release_link_number > latest_release_number:
@@ -57,3 +58,18 @@ class CentOSScraper(ArizonaMirror):
             (bool): is iso checksum file
         """
         return href.endswith("CHECKSUM")
+
+    def get_iso_version(self, iso_filename: str) -> str:
+        """
+        Extracts ISO version from release.
+
+        Returns:
+            str: iso version
+        """
+        filename_sections = self.get_filename_sections(iso_filename)
+
+        # If the filename was properly extracted, return it
+        if len(filename_sections) >= 2:
+            return filename_sections[2]
+
+        raise Exception(f"Could not extract {iso_filename} OS version")
