@@ -3,6 +3,8 @@ from latestos.scraper.arch import ArchScraper
 from latestos.scraper.centos import CentOSScraper
 from latestos.scraper.fedora import FedoraScraper
 from latestos.scraper.ubuntu import UbuntuScraper
+from latestos.scraper.debian import DebianScraper
+from latestos.scraper.raspbian import RaspbianScraper
 
 
 def get_os_scraper(os_name: str) -> BaseScraper:
@@ -22,5 +24,9 @@ def get_os_scraper(os_name: str) -> BaseScraper:
         return FedoraScraper()
     elif os_name == "ubuntu":
         return UbuntuScraper()
+    elif os_name == "debian":
+        return DebianScraper()
+    elif os_name == "raspbian":
+        return RaspbianScraper()
     else:
         raise ValueError(f"{os_name}")
